<?php
/**
 * Footer hooks and functions
 * 
 * @package Blogig
 * @since 1.0.0
 */
use Blogig\CustomizerDefault as BD;
if( ! function_exists( 'blogig_footer_widgets_area_part' ) ) :
   /**
    * Footer widgets area
    * 
    * @since 1.0.0
    */
   function blogig_footer_widgets_area_part() {
        $footer_widget_column = BD\blogig_get_customizer_option( 'footer_widget_column' );
    ?>
            <div class="footer-widget <?php echo esc_attr( $footer_widget_column ); ?>">
                <?php
                    if( ! is_active_sidebar( 'footer-sidebar--column-1' ) ) {
						dynamic_sidebar( esc_html__( 'Footer Sidebar - Column 1', 'blogig' ) );
					} else {
						dynamic_sidebar( 'footer-sidebar--column-1' );
					}
                ?>
            </div>
        <?php
            if( $footer_widget_column !== 'column-one' ) {
            ?>
                <div class="footer-widget <?php echo esc_attr( $footer_widget_column ); ?>">
                    <?php
                        if( ! is_active_sidebar( 'footer-sidebar--column-2' ) ) {
                            dynamic_sidebar( esc_html__( 'Footer Sidebar - Column 2', 'blogig' ) );
                        } else {
                            dynamic_sidebar( 'footer-sidebar--column-2' );
                        }
                    ?>
                </div>
        <?php
            }

            if( $footer_widget_column === 'column-four' || $footer_widget_column === 'column-three' ) {
            ?>
                <div class="footer-widget <?php echo esc_attr( $footer_widget_column ); ?>">
                    <?php
                        if( ! is_active_sidebar( 'footer-sidebar--column-3' ) ) {
                            dynamic_sidebar( esc_html__( 'Footer Sidebar - Column 3', 'blogig' ) );
                        } else {
                            dynamic_sidebar( 'footer-sidebar--column-3' );
                        }
                    ?>
                </div>
        <?php
            }

            if( $footer_widget_column === 'column-four' ) {
                ?>
                    <div class="footer-widget <?php echo esc_attr( $footer_widget_column ); ?>">
                        <?php
                            if( ! is_active_sidebar( 'footer-sidebar--column-4' ) ) {
                                dynamic_sidebar( esc_html__( 'Footer Sidebar - Column 4', 'blogig' ) );
                            } else {
                                dynamic_sidebar( 'footer-sidebar--column-4' );
                            }
                        ?>
                    </div>
        <?php
            }
   }
   add_action( 'blogig_footer_hook', 'blogig_footer_widgets_area_part', 10 );
endif;

if( ! function_exists( 'blogig_bottom_footer_logo_part' ) ) :
    /**
     * Bottom Footer logo element
     * 
     * @since 1.0.0
     */
    function blogig_bottom_footer_logo_part() {
        if( ! BD\blogig_get_customizer_option( 'bottom_footer_show_logo' ) ) return;
        $logo_from = BD\blogig_get_customizer_option( 'bottom_footer_header_or_custom' );
        if( $logo_from == 'header' ) :
            $footer_logo = get_theme_mod( 'custom_logo' );
        else:
            $footer_logo = BD\blogig_get_customizer_option( 'bottom_footer_logo_option' );
        endif;
        ?>
            <div class="footer-logo">
                <?php echo wp_get_attachment_image( $footer_logo, 'full' ); ?>        
            </div>
        <?php
    }
    add_action( 'blogig_botttom_footer_hook', 'blogig_bottom_footer_logo_part', 19 );
endif;

 if( ! function_exists( 'blogig_bottom_footer_copyright_part' ) ) :
   /**
    * Bottom Footer copyright element
    * 
    * @since 1.0.0
    */
    function blogig_bottom_footer_copyright_part() {
      $bottom_footer_site_info = BD\blogig_get_customizer_option( 'bottom_footer_site_info' );
      if( ! $bottom_footer_site_info ) return;
     ?>
        <div class="site-info">
            <?php echo wp_kses_post( str_replace( '%year%', date('Y'), $bottom_footer_site_info ) ); ?>
				<?php echo sprintf( esc_html( 'Developed By %s.', 'blogig' ), '<a href="https://blazethemes.com/">' .esc_html( 'BlazeThemes' ). '</a>'  ); ?>
        </div>
     <?php
   }
   add_action( 'blogig_botttom_footer_hook', 'blogig_bottom_footer_copyright_part', 20 );
endif;

if( ! function_exists( 'blogig_bottom_footer_inner_wrapper_open' ) ) :
   /**
    * Bottom Footer inner wrapper open
    * 
    * @since 1.0.0
    */
   function blogig_bottom_footer_inner_wrapper_open() {
      ?>
         <div class="bottom-inner-wrapper">
      <?php
   }
   add_action( 'blogig_botttom_footer_hook', 'blogig_bottom_footer_inner_wrapper_open', 15 );
endif;

if( ! function_exists( 'blogig_bottom_footer_inner_wrapper_close' ) ) :
   /**
    * Bottom Footer inner wrapper close
    * 
    * @since 1.0.0
    */
   function blogig_bottom_footer_inner_wrapper_close() {
      ?>
         </div><!-- .bottom-inner-wrapper -->
      <?php
   }
   add_action( 'blogig_botttom_footer_hook', 'blogig_bottom_footer_inner_wrapper_close', 40 );
endif;